pub struct PictorConfig {
pub server: ServerConfig,
pub sampling: SamplingConfig,
pub model: ModelConfig,
pub observability: ObservabilityConfig,
}Expand description
Top-level Pictor configuration.
Fields
server: ServerConfigServer configuration.
sampling: SamplingConfigSampling parameters.
model: ModelConfigModel paths and limits.
observability: ObservabilityConfigObservability settings.
Implementations
Sourceimpl PictorConfig
impl PictorConfig
Sourcepub fn load(path: &Path) -> RuntimeResult<Self>
pub fn load(path: &Path) -> RuntimeResult<Self>
Load configuration from a TOML file.
Sourcepub fn load_or_default(path: Option<&Path>) -> Self
pub fn load_or_default(path: Option<&Path>) -> Self
Load configuration from a TOML file if a path is given, otherwise return defaults.
Sourcepub fn validate(&self) -> RuntimeResult<()>
pub fn validate(&self) -> RuntimeResult<()>
Validate this configuration, returning an error if any field is invalid.
Sourcepub fn dry_run_check(&self) -> Vec<ConfigWarning>
pub fn dry_run_check(&self) -> Vec<ConfigWarning>
Run a dry-run check of this configuration.
Returns warnings about potential issues without stopping execution. Checks for model file existence, tokenizer existence, and reasonable parameter values.